You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hudi.apache.org by "RuyRoaV (via GitHub)" <gi...@apache.org> on 2024/07/03 20:32:11 UTC
Re: [I] [SUPPORT] - Performance Variation in Hudi 0.14 [hudi]
RuyRoaV commented on issue #11481:
URL: https://github.com/apache/hudi/issues/11481#issuecomment-2207209448
Hi Aditya
I have tried out your recommendation and found the following:
** Using SIMPLE INDEX**
The average execution time was reduced from 20 min to around 11 min, which is great. In the Spark UI screenshot, you can see that a big percentage of the execution time is taken by a `countByKey at JavePairRDD` action in the `SparkCommitUpsert` executor, especially during the `SuffleWrite` part.



**We are in a need to reduce the job runtime even more, is there any other recommendation regarding the different configurations that we can set?**
We may try deactivating of the archival beyond the savepoint a bit later. But I am curious about why would that help us improve in performance?
**Using RECORD LEVEL**
I replaced the index for a table, for which its upsert Glue job was already running in under 5 minutes. Overall, the job runtime has remained the same, being `count at HoodieSparkSqlWriter.scala:1072` during the `SparkCommitUpsert`, especially during the execution. This is similar as in the case presented when submitting this ticket.
I'll try with one of our long running jobs and will let you know the outcome.
By the way **is there a way to check the index type of a table?**
Thanks
Best regards
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: commits-unsubscribe@hudi.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org